@@ -1,4 +1,4 @@
-SENTINEL1 = 'Sentinel-1'
+SENTINEL1 = 'SENTINEL-1'
 SENTINEL1A = 'Sentinel-1A'
 SENTINEL1B = 'Sentinel-1B'
 SIRC = 'SIR-C'
