@@ -2,7 +2,7 @@ from .search import search
 from .granule_search import granule_search
 from .product_search import product_search
 from .geo_search import geo_search
-from .baseline_search import stack_from_id, get_stack_opts
+from .baseline_search import stack_from_id
 from .campaigns import campaigns
 from .search_count import search_count
 from .search_generator import search_generator
\ No newline at end of file
