@@ -1,4 +1,4 @@
-from typing import Iterable
+from typing import Sequence
 from copy import copy
 
 from asf_search.search import search
@@ -7,8 +7,8 @@ from asf_search.ASFSearchResults import ASFSearchResults
 
 
 def granule_search(
-        granule_list: Iterable[str],
-        opts: ASFSearchOptions = None,
+        granule_list: Sequence[str],
+        opts: ASFSearchOptions = None
 ) -> ASFSearchResults:
     """
     Performs a granule name search using the ASF SearchAPI
